@@ -1,7 +1,7 @@
 /*!
  * VisualEditor DataModel DefinitionListNode class.
  *
- * @copyright 2011-2020 VisualEditor Team and others; see http://ve.mit-license.org
+ * @copyright See AUTHORS.txt
  */
 
 /**
@@ -33,6 +33,15 @@ ve.dm.DefinitionListNode.static.matchTagNames = [ 'dl' ];
 
 ve.dm.DefinitionListNode.static.isDiffedAsList = true;
 
+// Nodes which are diffed as a list must have the same description logic as each other
+ve.dm.DefinitionListNode.static.describeChanges = function () {
+	return ve.dm.ListNode.static.describeChanges.apply( this, arguments );
+};
+
+ve.dm.DefinitionListNode.static.describeChange = function () {
+	return ve.dm.ListNode.static.describeChange.apply( this, arguments );
+};
+
 /* Registration */
 
 ve.dm.modelRegistry.register( ve.dm.DefinitionListNode );
