@@ -1,7 +1,7 @@
 /*!
  * VisualEditor user interface MWMetaDialog class.
  *
- * @copyright 2011-2020 VisualEditor Team and others; see AUTHORS.txt
+ * @copyright See AUTHORS.txt
  * @license The MIT License (MIT); see LICENSE.txt
  */
 
@@ -77,7 +77,7 @@ ve.ui.MWMetaDialog.prototype.initialize = function () {
  * @return {boolean} Whether settings were changed.
  */
 ve.ui.MWMetaDialog.prototype.compareSettings = function () {
-	var newSettings = this.extractSettings();
+	const newSettings = this.extractSettings();
 	return !ve.compare( newSettings, this.oldSettings );
 };
 
@@ -90,14 +90,14 @@ ve.ui.MWMetaDialog.prototype.compareSettings = function () {
  * }
  */
 ve.ui.MWMetaDialog.prototype.getAllWidgets = function () {
-	var widgetList = [];
+	const widgetList = [];
 
 	// eslint-disable-next-line no-jquery/no-each-util
-	$.each( this.bookletLayout.pages, function ( pageName, page ) {
-		var fieldsets = page.getFieldsets();
-		fieldsets.forEach( function ( fieldset, fieldsetIndex ) {
-			fieldset.items.forEach( function ( item, itemIndex ) {
-				var widget = item.fieldWidget;
+	$.each( this.bookletLayout.pages, ( pageName, page ) => {
+		const fieldsets = page.getFieldsets();
+		fieldsets.forEach( ( fieldset, fieldsetIndex ) => {
+			fieldset.items.forEach( ( item, itemIndex ) => {
+				const widget = item.fieldWidget;
 				// we can recheck the value
 				widgetList.push( {
 					widget: widget,
@@ -115,11 +115,10 @@ ve.ui.MWMetaDialog.prototype.getAllWidgets = function () {
  * Assigns updateActions to all widget updates.
  */
 ve.ui.MWMetaDialog.prototype.assignEvents = function () {
-	var widgetList = this.getAllWidgets(),
-		dialog = this;
+	const widgetList = this.getAllWidgets();
 
-	widgetList.forEach( function ( value ) {
-		value.widget.connect( dialog, {
+	widgetList.forEach( ( value ) => {
+		value.widget.connect( this, {
 			change: 'updateActions',
 			select: 'updateActions'
 		} );
@@ -154,21 +153,20 @@ ve.ui.MWMetaDialog.prototype.extractValue = function ( field ) {
  * }
  */
 ve.ui.MWMetaDialog.prototype.extractSettings = function () {
-	var ret = [],
-		dialog = this; // return value
+	const ret = []; // return value
 
-	this.widgetList.forEach( function ( value ) {
+	this.widgetList.forEach( ( value ) => {
 		if ( value.hasChildren ) {
-			value.widget.items.forEach( function ( item, index ) {
+			value.widget.items.forEach( ( item, index ) => {
 				ret.push( {
 					name: item.name + '/' + index,
-					value: dialog.extractValue( item )
+					value: this.extractValue( item )
 				} );
 			} );
 		} else {
 			ret.push( {
 				name: value.name,
-				value: dialog.extractValue( value.widget )
+				value: this.extractValue( value.widget )
 			} );
 		}
 	} );
@@ -197,19 +195,19 @@ ve.ui.MWMetaDialog.prototype.isEditing = function () {
  * @inheritdoc
  */
 ve.ui.MWMetaDialog.prototype.getActionProcess = function ( action ) {
-	var surfaceModel = this.getFragment().getSurface();
+	const surfaceModel = this.getFragment().getSurface();
 
 	if ( action === 'done' ) {
-		return new OO.ui.Process( function () {
+		return new OO.ui.Process( () => {
 			surfaceModel.applyStaging();
 			this.close( { action: action } );
-		}, this );
+		} );
 	}
 
 	return ve.ui.MWMetaDialog.super.prototype.getActionProcess.call( this, action )
-		.next( function () {
+		.next( () => {
 			surfaceModel.popStaging();
-		}, this );
+		} );
 };
 
 /**
@@ -218,14 +216,14 @@ ve.ui.MWMetaDialog.prototype.getActionProcess = function ( action ) {
 ve.ui.MWMetaDialog.prototype.getSetupProcess = function ( data ) {
 	data = data || {};
 	return ve.ui.MWMetaDialog.super.prototype.getSetupProcess.call( this, data )
-		.next( function () {
-			var surfaceModel = this.getFragment().getSurface(),
+		.next( () => {
+			const surfaceModel = this.getFragment().getSurface(),
 				promises = [],
 				selectWidget = this.bookletLayout.outlineSelectWidget,
 				visualOnlyPages = [ 'categories', 'settings', 'advancedSettings', 'languages' ],
 				isSource = ve.init.target.getSurface().getMode() === 'source';
 
-			visualOnlyPages.forEach( function ( page ) {
+			visualOnlyPages.forEach( ( page ) => {
 				selectWidget.findItemFromData( page ).setDisabled( isSource );
 			} );
 
@@ -236,18 +234,18 @@ ve.ui.MWMetaDialog.prototype.getSetupProcess = function ( data ) {
 			// Force all previous transactions to be separate from this history state
 			surfaceModel.pushStaging();
 
-			var config = {
+			const config = {
 				data: data,
 				isReadOnly: this.isReadOnly()
 			};
 
 			// Let each page set itself up ('languages' page doesn't need this yet)
-			promises.push( this.categoriesPage.setup( surfaceModel.metaList, config ) );
-			promises.push( this.settingsPage.setup( surfaceModel.metaList, config ) );
-			promises.push( this.advancedSettingsPage.setup( surfaceModel.metaList, config ) );
+			promises.push( this.categoriesPage.setup( surfaceModel.getFragment(), config ) );
+			promises.push( this.settingsPage.setup( surfaceModel.getFragment(), config ) );
+			promises.push( this.advancedSettingsPage.setup( surfaceModel.getFragment(), config ) );
 			return ve.promiseAll( promises );
-		}, this )
-		.next( function () {
+		} )
+		.next( () => {
 			if ( data.page && this.bookletLayout.getPage( data.page ) ) {
 				// HACK: Prevent the setPage() call from focussing stuff in the selected page. For the
 				// 'categories' page, this causes a dropdown to appear, and if it's done in the setup
@@ -265,7 +263,7 @@ ve.ui.MWMetaDialog.prototype.getSetupProcess = function ( data ) {
 			this.oldSettings = this.extractSettings(); // setting that were just loaded
 
 			this.actions.setAbilities( { done: false } );
-		}, this );
+		} );
 };
 
 /**
@@ -274,11 +272,11 @@ ve.ui.MWMetaDialog.prototype.getSetupProcess = function ( data ) {
 ve.ui.MWMetaDialog.prototype.getReadyProcess = function ( data ) {
 	data = data || {};
 	return ve.ui.MWMetaDialog.super.prototype.getReadyProcess.call( this, data )
-		.next( function () {
+		.next( () => {
 			if ( data.page && this.bookletLayout.getPage( data.page ) ) {
 				this.bookletLayout.getPage( data.page ).focus();
 			}
-		}, this );
+		} );
 };
 
 /**
@@ -287,7 +285,7 @@ ve.ui.MWMetaDialog.prototype.getReadyProcess = function ( data ) {
 ve.ui.MWMetaDialog.prototype.getTeardownProcess = function ( data ) {
 	data = data || {};
 	return ve.ui.MWMetaDialog.super.prototype.getTeardownProcess.call( this, data )
-		.first( function () {
+		.first( () => {
 			// Let each page tear itself down ('languages' page doesn't need this yet)
 			this.categoriesPage.teardown( { action: data.action } );
 			this.settingsPage.teardown( { action: data.action } );
@@ -295,7 +293,7 @@ ve.ui.MWMetaDialog.prototype.getTeardownProcess = function ( data ) {
 
 			this.bookletLayout.setPage( 'categories' );
 			this.bookletLayout.resetScroll();
-		}, this );
+		} );
 };
 
 /* Registration */
