@@ -3,7 +3,7 @@
 namespace MediaWiki\Hook;
 
 use File;
-use Title;
+use MediaWiki\Title\Title;
 
 /**
  * This is a hook handler interface, see docs/Hooks.md.
