@@ -24,6 +24,7 @@ use InvalidArgumentException;
 use MediaWiki\Block\Block;
 use MediaWiki\Page\PageIdentity;
 use MediaWiki\User\UserIdentity;
+use Wikimedia\Rdbms\IDBAccessObject;
 
 /**
  * Represents an authority that has all permissions.
@@ -50,39 +51,22 @@ class UltimateAuthority implements Authority {
 		$this->isTemp = $isTemp;
 	}
 
-	/**
-	 * The user identity associated with this authority.
-	 *
-	 * @return UserIdentity
-	 */
+	/** @inheritDoc */
 	public function getUser(): UserIdentity {
 		return $this->actor;
 	}
 
-	/**
-	 * @param int $freshness
-	 *
-	 * @return ?Block always null
-	 * @since 1.37
-	 */
-	public function getBlock( int $freshness = self::READ_NORMAL ): ?Block {
+	/** @inheritDoc */
+	public function getBlock( int $freshness = IDBAccessObject::READ_NORMAL ): ?Block {
 		return null;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @return bool
-	 */
-	public function isAllowed( string $permission ): bool {
+	/** @inheritDoc */
+	public function isAllowed( string $permission, ?PermissionStatus $status = null ): bool {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
 	public function isAllowedAny( ...$permissions ): bool {
 		if ( !$permissions ) {
 			throw new InvalidArgumentException( 'At least one permission must be specified' );
@@ -91,11 +75,7 @@ class UltimateAuthority implements Authority {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
 	public function isAllowedAll( ...$permissions ): bool {
 		if ( !$permissions ) {
 			throw new InvalidArgumentException( 'At least one permission must be specified' );
@@ -104,70 +84,48 @@ class UltimateAuthority implements Authority {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @param string $action
-	 * @param PageIdentity $target
-	 * @param PermissionStatus|null $status
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
 	public function probablyCan(
 		string $action,
 		PageIdentity $target,
-		PermissionStatus $status = null
+		?PermissionStatus $status = null
 	): bool {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @param string $action
-	 * @param PageIdentity $target
-	 * @param PermissionStatus|null $status
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
 	public function definitelyCan(
 		string $action,
 		PageIdentity $target,
-		PermissionStatus $status = null
+		?PermissionStatus $status = null
 	): bool {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @param string $action
-	 * @param PageIdentity $target
-	 * @param PermissionStatus|null $status
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
+	public function isDefinitelyAllowed( string $action, ?PermissionStatus $status = null ): bool {
+		return true;
+	}
+
+	/** @inheritDoc */
+	public function authorizeAction( string $action, ?PermissionStatus $status = null ): bool {
+		return true;
+	}
+
+	/** @inheritDoc */
 	public function authorizeRead(
 		string $action,
 		PageIdentity $target,
-		PermissionStatus $status = null
+		?PermissionStatus $status = null
 	): bool {
 		return true;
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @param string $action
-	 * @param PageIdentity $target
-	 * @param PermissionStatus|null $status
-	 *
-	 * @return bool
-	 */
+	/** @inheritDoc */
 	public function authorizeWrite(
 		string $action,
 		PageIdentity $target,
-		PermissionStatus $status = null
+		?PermissionStatus $status = null
 	): bool {
 		return true;
 	}
