@@ -24,16 +24,16 @@ namespace MediaWiki\ResourceLoader;
 
 use MediaWiki\Logger\LoggerFactory;
 use MediaWiki\MediaWikiServices;
+use MediaWiki\Message\Message;
 use MediaWiki\Page\PageReferenceValue;
 use MediaWiki\Request\FauxRequest;
 use MediaWiki\Request\WebRequest;
 use MediaWiki\User\User;
 use MediaWiki\User\UserIdentity;
 use MediaWiki\User\UserRigorOptions;
-use Message;
 use MessageLocalizer;
-use MessageSpecifier;
 use Psr\Log\LoggerInterface;
+use Wikimedia\Message\MessageSpecifier;
 
 /**
  * Context object that contains information about the state of a specific
@@ -102,8 +102,12 @@ class Context implements MessageLocalizer {
 	/**
 	 * @param ResourceLoader $resourceLoader
 	 * @param WebRequest $request
+	 * @param string[]|null $validSkins List of valid skin names. If not passed,
+	 *   any skin name is considered valid. Invalid skins are replaced by the default.
 	 */
-	public function __construct( ResourceLoader $resourceLoader, WebRequest $request ) {
+	public function __construct(
+		ResourceLoader $resourceLoader, WebRequest $request, $validSkins = null
+	) {
 		$this->resourceLoader = $resourceLoader;
 		$this->request = $request;
 		$this->logger = $resourceLoader->getLogger();
@@ -128,16 +132,16 @@ class Context implements MessageLocalizer {
 		$this->variant = $request->getRawVal( 'variant' );
 		$this->format = $request->getRawVal( 'format' );
 
-		$this->skin = $request->getRawVal( 'skin' );
-		$skinFactory = MediaWikiServices::getInstance()->getSkinFactory();
-		$skinnames = $skinFactory->getInstalledSkins();
-
-		if ( !$this->skin || !isset( $skinnames[$this->skin] ) ) {
-			// The 'skin' parameter is required. (Not yet enforced.)
+		$skin = $request->getRawVal( 'skin' );
+		if (
+			$skin === null
+			|| ( is_array( $validSkins ) && !in_array( $skin, $validSkins ) )
+		) {
 			// For requests without a known skin specified,
-			// use MediaWiki's 'fallback' skin for skin-specific decisions.
-			$this->skin = self::DEFAULT_SKIN;
+			// use MediaWiki's 'fallback' skin for any skin-specific decisions.
+			$skin = self::DEFAULT_SKIN;
 		}
+		$this->skin = $skin;
 	}
 
 	/**
@@ -206,8 +210,7 @@ class Context implements MessageLocalizer {
 		if ( $this->language === null ) {
 			// Must be a valid language code after this point (T64849)
 			// Only support uselang values that follow built-in conventions (T102058)
-			$lang = $this->getRequest()->getRawVal( 'lang', '' );
-			'@phan-var string $lang'; // getRawVal does not return null here
+			$lang = $this->getRequest()->getRawVal( 'lang' ) ?? '';
 			// Stricter version of RequestContext::sanitizeLangCode()
 			$validBuiltinCode = MediaWikiServices::getInstance()->getLanguageNameUtils()
 				->isValidBuiltInCode( $lang );
@@ -300,13 +303,13 @@ class Context implements MessageLocalizer {
 	public function getUserObj(): User {
 		if ( $this->userObj === null ) {
 			$username = $this->getUser();
+			$userFactory = MediaWikiServices::getInstance()->getUserFactory();
 			if ( $username ) {
 				// Use provided username if valid, fallback to anonymous user
-				$this->userObj = User::newFromName( $username ) ?: new User;
-			} else {
-				// Anonymous user
-				$this->userObj = new User;
+				$this->userObj = $userFactory->newFromName( $username, UserRigorOptions::RIGOR_VALID );
 			}
+			// Anonymous user
+			$this->userObj ??= $userFactory->newAnonymous();
 		}
 
 		return $this->userObj;
@@ -515,6 +518,3 @@ class Context implements MessageLocalizer {
 		return $json;
 	}
 }
-
-/** @deprecated since 1.39 */
-class_alias( Context::class, 'ResourceLoaderContext' );
