@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright © 2007 Roan Kattouw "<Firstname>.<Lastname>@gmail.com"
+ * Copyright © 2007 Roan Kattouw <roan.kattouw@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,13 @@
  * @file
  */
 
+namespace MediaWiki\Api;
+
+use ChangeTags;
 use MediaWiki\MainConfigNames;
 use MediaWiki\Permissions\RestrictionStore;
-use MediaWiki\User\UserOptionsLookup;
+use MediaWiki\Title\Title;
+use MediaWiki\User\Options\UserOptionsLookup;
 use MediaWiki\Watchlist\WatchlistManager;
 use Wikimedia\ParamValidator\ParamValidator;
 
@@ -33,19 +37,11 @@ class ApiProtect extends ApiBase {
 
 	use ApiWatchlistTrait;
 
-	/** @var RestrictionStore */
-	private $restrictionStore;
+	private RestrictionStore $restrictionStore;
 
-	/**
-	 * @param ApiMain $mainModule
-	 * @param string $moduleName
-	 * @param WatchlistManager $watchlistManager
-	 * @param UserOptionsLookup $userOptionsLookup
-	 * @param RestrictionStore $restrictionStore
-	 */
 	public function __construct(
 		ApiMain $mainModule,
-		$moduleName,
+		string $moduleName,
 		WatchlistManager $watchlistManager,
 		UserOptionsLookup $userOptionsLookup,
 		RestrictionStore $restrictionStore
@@ -235,3 +231,6 @@ class ApiProtect extends ApiBase {
 		return 'https://www.mediawiki.org/wiki/Special:MyLanguage/API:Protect';
 	}
 }
+
+/** @deprecated class alias since 1.43 */
+class_alias( ApiProtect::class, 'ApiProtect' );
