@@ -536,7 +536,7 @@ abstract class ApiQueryRevisionsBase extends ApiQueryGeneratorBase {
 				$vals['slots'][$role] = $this->extractSlotInfo( $slot, $revDel, $content );
 				// @todo Move this into extractSlotInfo() (and remove its $content parameter)
 				// when extractDeprecatedContent() is no more.
-				if ( $content ) {
+				if ( $content && $this->getAuthority()->authorizeRead( 'read', $revision->getPage() ) ) {
 					/** @var Content $content */
 					$model = $content->getModel();
 					$format = $this->slotContentFormats[$role] ?? $content->getDefaultFormat();
@@ -636,6 +636,10 @@ abstract class ApiQueryRevisionsBase extends ApiQueryGeneratorBase {
 		$vals = [];
 		$title = Title::newFromLinkTarget( $revision->getPageAsLinkTarget() );
 
+		if ( !$this->getAuthority()->authorizeRead( 'read', $title ) ) {
+			return [];
+		}
+
 		if ( $this->fld_parsetree || ( $this->fld_content && $this->generateXML ) ) {
 			if ( $content->getModel() === CONTENT_MODEL_WIKITEXT ) {
 				/** @var WikitextContent $content */
