@@ -2,7 +2,7 @@
 /**
  * Base class for exporting
  *
- * Copyright © 2003, 2005, 2006 Brion Vibber <brion@pobox.com>
+ * Copyright © 2003, 2005, 2006 Brooke Vibber <bvibber@wikimedia.org>
  * https://www.mediawiki.org/
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,8 @@
  * @defgroup Dump Dump
  */
 
+use MediaWiki\CommentStore\CommentStore;
+use MediaWiki\Debug\MWDebug;
 use MediaWiki\HookContainer\HookContainer;
 use MediaWiki\HookContainer\HookRunner;
 use MediaWiki\MainConfigNames;
@@ -35,7 +37,9 @@ use MediaWiki\Page\PageIdentity;
 use MediaWiki\Revision\RevisionAccessException;
 use MediaWiki\Revision\RevisionRecord;
 use MediaWiki\Revision\RevisionStore;
-use Wikimedia\Rdbms\IDatabase;
+use MediaWiki\Title\MalformedTitleException;
+use MediaWiki\Title\TitleParser;
+use Wikimedia\Rdbms\IReadableDatabase;
 use Wikimedia\Rdbms\IResultWrapper;
 
 /**
@@ -63,7 +67,7 @@ class WikiExporter {
 	public const TEXT = XmlDumpWriter::WRITE_CONTENT;
 	public const STUB = XmlDumpWriter::WRITE_STUB;
 
-	protected const BATCH_SIZE = 50000;
+	protected const BATCH_SIZE = 10000;
 
 	/** @var int */
 	public $text;
@@ -74,7 +78,7 @@ class WikiExporter {
 	/** @var XmlDumpWriter */
 	private $writer;
 
-	/** @var IDatabase */
+	/** @var IReadableDatabase */
 	protected $db;
 
 	/** @var array|int */
@@ -92,6 +96,9 @@ class WikiExporter {
 	/** @var HookRunner */
 	private $hookRunner;
 
+	/** @var CommentStore */
+	private $commentStore;
+
 	/**
 	 * Returns the default export schema version, as defined by the XmlDumpSchemaVersion setting.
 	 * @return string
@@ -102,7 +109,8 @@ class WikiExporter {
 	}
 
 	/**
-	 * @param IDatabase $db
+	 * @param IReadableDatabase $db
+	 * @param CommentStore $commentStore
 	 * @param HookContainer $hookContainer
 	 * @param RevisionStore $revisionStore
 	 * @param TitleParser $titleParser
@@ -116,6 +124,7 @@ class WikiExporter {
 	 */
 	public function __construct(
 		$db,
+		CommentStore $commentStore,
 		HookContainer $hookContainer,
 		RevisionStore $revisionStore,
 		TitleParser $titleParser,
@@ -124,10 +133,14 @@ class WikiExporter {
 		$limitNamespaces = null
 	) {
 		$this->db = $db;
+		$this->commentStore = $commentStore;
 		$this->history = $history;
-		// TODO: add a $hookContainer parameter to XmlDumpWriter so that we can inject
-		// and then be able to convert the factory test to a unit test
-		$this->writer = new XmlDumpWriter( $text, self::schemaVersion() );
+		$this->writer = new XmlDumpWriter(
+			$text,
+			self::schemaVersion(),
+			$hookContainer,
+			$commentStore
+		);
 		$this->sink = new DumpOutput();
 		$this->text = $text;
 		$this->limitNamespaces = $limitNamespaces;
@@ -224,7 +237,6 @@ class WikiExporter {
 
 	/**
 	 * @param string $name
-	 * @throws MWException
 	 */
 	public function pageByName( $name ) {
 		try {
@@ -233,7 +245,7 @@ class WikiExporter {
 				'page_namespace=' . $link->getNamespace() .
 				' AND page_title=' . $this->db->addQuotes( $link->getDBkey() ) );
 		} catch ( MalformedTitleException $ex ) {
-			throw new MWException( "Can't export invalid title" );
+			throw new RuntimeException( "Can't export invalid title" );
 		}
 	}
 
@@ -273,21 +285,12 @@ class WikiExporter {
 		$this->author_list = "<contributors>";
 		// rev_deleted
 
-		$revQuery = $this->revisionStore->getQueryInfo( [ 'page' ] );
-		$res = $this->db->select(
-			$revQuery['tables'],
-			[
-				'rev_user_text' => $revQuery['fields']['rev_user_text'],
-				'rev_user' => $revQuery['fields']['rev_user'],
-			],
-			[
-				$this->db->bitAnd( 'rev_deleted', RevisionRecord::DELETED_USER ) . ' = 0',
-				$cond,
-			],
-			__METHOD__,
-			[ 'DISTINCT' ],
-			$revQuery['joins']
-		);
+		$res = $this->revisionStore->newSelectQueryBuilder( $this->db )
+			->joinPage()
+			->distinct()
+			->where( $this->db->bitAnd( 'rev_deleted', RevisionRecord::DELETED_USER ) . ' = 0' )
+			->andWhere( $cond )
+			->caller( __METHOD__ )->fetchResultSet();
 
 		foreach ( $res as $row ) {
 			$this->author_list .= "<contributor>" .
@@ -305,8 +308,6 @@ class WikiExporter {
 	/**
 	 * @param string $cond
 	 * @param bool $orderRevs
-	 * @throws MWException
-	 * @throws Exception
 	 */
 	protected function dumpFrom( $cond = '', $orderRevs = false ) {
 		if ( is_int( $this->history ) && ( $this->history & self::LOGS ) ) {
@@ -318,7 +319,6 @@ class WikiExporter {
 
 	/**
 	 * @param string $cond
-	 * @throws Exception
 	 */
 	protected function dumpLogs( $cond ) {
 		$where = [];
@@ -331,36 +331,26 @@ class WikiExporter {
 		if ( $cond ) {
 			$where[] = $cond;
 		}
-		$result = null; // Assuring $result is not undefined, if exception occurs early
 
-		$commentQuery = CommentStore::getStore()->getJoin( 'log_comment' );
-
-		$tables = array_merge(
-			[ 'logging', 'actor' ], $commentQuery['tables']
-		);
-		$fields = [
-			'log_id', 'log_type', 'log_action', 'log_timestamp', 'log_namespace',
-			'log_title', 'log_params', 'log_deleted', 'actor_user', 'actor_name'
-		] + $commentQuery['fields'];
-		$options = [
-			'ORDER BY' => 'log_id',
-			'USE INDEX' => [ 'logging' => 'PRIMARY' ],
-			'LIMIT' => self::BATCH_SIZE,
-		];
-		$joins = [
-			'actor' => [ 'JOIN', 'actor_id=log_actor' ]
-		] + $commentQuery['joins'];
+		$commentQuery = $this->commentStore->getJoin( 'log_comment' );
 
 		$lastLogId = 0;
 		while ( true ) {
-			$result = $this->db->select(
-				$tables,
-				$fields,
-				array_merge( $where, [ 'log_id > ' . intval( $lastLogId ) ] ),
-				__METHOD__,
-				$options,
-				$joins
-			);
+			$result = $this->db->newSelectQueryBuilder()
+				->select( [
+					'log_id', 'log_type', 'log_action', 'log_timestamp', 'log_namespace',
+					'log_title', 'log_params', 'log_deleted', 'actor_user', 'actor_name'
+				] )
+				->from( 'logging' )
+				->join( 'actor', null, 'actor_id=log_actor' )
+				->where( $where )
+				->andWhere( $this->db->expr( 'log_id', '>', intval( $lastLogId ) ) )
+				->orderBy( 'log_id' )
+				->useIndex( [ 'logging' => 'PRIMARY' ] )
+				->limit( self::BATCH_SIZE )
+				->queryInfo( $commentQuery )
+				->caller( __METHOD__ )
+				->fetchResultSet();
 
 			if ( !$result->numRows() ) {
 				break;
@@ -374,8 +364,6 @@ class WikiExporter {
 	/**
 	 * @param string $cond
 	 * @param bool $orderRevs
-	 * @throws MWException
-	 * @throws Exception
 	 */
 	protected function dumpPages( $cond, $orderRevs ) {
 		$revQuery = $this->revisionStore->getQueryInfo( [ 'page' ] );
@@ -448,16 +436,15 @@ class WikiExporter {
 			$join['revision'] = [ 'JOIN', 'page_id=rev_page AND page_latest=rev_id' ];
 			# One, and only one hook should set this, and return false
 			if ( $this->hookRunner->onWikiExporter__dumpStableQuery( $tables, $opts, $join ) ) {
-				throw new MWException( __METHOD__ . " given invalid history dump type." );
+				throw new LogicException( __METHOD__ . " given invalid history dump type." );
 			}
 		} elseif ( $this->history & self::RANGE ) {
 			# Dump of revisions within a specified range.  Condition already set in revsByRange().
 		} else {
 			# Unknown history specification parameter?
-			throw new MWException( __METHOD__ . " given invalid history dump type." );
+			throw new UnexpectedValueException( __METHOD__ . " given invalid history dump type." );
 		}
 
-		$result = null; // Assuring $result is not undefined, if exception occurs early
 		$done = false;
 		$lastRow = null;
 		$revPage = 0;
@@ -476,19 +463,18 @@ class WikiExporter {
 				$done = true;
 			}
 
-			$queryConds = $conds;
-			$queryConds[] = 'rev_page>' . intval( $revPage ) . ' OR (rev_page=' .
-				intval( $revPage ) . ' AND rev_id' . $op . intval( $revId ) . ')';
-
 			# Do the query and process any results, remembering max ids for the next iteration.
-			$result = $this->db->select(
-				$tables,
-				$fields,
-				$queryConds,
-				__METHOD__,
-				$opts,
-				$join
-			);
+			$result = $this->db->newSelectQueryBuilder()
+				->tables( $tables )
+				->fields( $fields )
+				->where( $conds )
+				->andWhere( $this->db->expr( 'rev_page', '>', intval( $revPage ) )->orExpr(
+					$this->db->expr( 'rev_page', '=', intval( $revPage ) )->and( 'rev_id', $op, intval( $revId ) )
+				) )
+				->caller( __METHOD__ )
+				->options( $opts )
+				->joinConds( $join )
+				->fetchResultSet();
 			if ( $result->numRows() > 0 ) {
 				$lastRow = $this->outputPageStreamBatch( $result, $lastRow );
 				$rowCount += $result->numRows();
@@ -588,6 +574,8 @@ class WikiExporter {
 			$carry = null;
 		}
 
+		// Reading further rows from the result set for the same rev id
+		// phpcs:ignore Generic.CodeAnalysis.AssignmentInCondition.FoundInWhileCondition
 		while ( $row = $results->fetchObject() ) {
 			if ( $prev && $prev->rev_id !== $row->rev_id ) {
 				$carry = $row;
