@@ -21,14 +21,15 @@ namespace MediaWiki\Http;
 
 use GuzzleHttp\Client;
 use GuzzleHttpRequest;
+use InvalidArgumentException;
 use MediaWiki\Config\ServiceOptions;
 use MediaWiki\Logger\LoggerFactory;
 use MediaWiki\MainConfigNames;
-use MultiHttpClient;
+use MediaWiki\Status\Status;
 use MWHttpRequest;
 use Profiler;
 use Psr\Log\LoggerInterface;
-use Status;
+use Wikimedia\Http\MultiHttpClient;
 
 /**
  * Factory creating MWHttpRequest objects.
@@ -38,6 +39,8 @@ class HttpRequestFactory {
 	private $options;
 	/** @var LoggerInterface */
 	private $logger;
+	/** @var Telemetry|null */
+	private $telemetry;
 
 	/**
 	 * @internal For use by ServiceWiring
@@ -51,10 +54,15 @@ class HttpRequestFactory {
 		MainConfigNames::LocalHTTPProxy,
 	];
 
-	public function __construct( ServiceOptions $options, LoggerInterface $logger ) {
+	public function __construct(
+		ServiceOptions $options,
+		LoggerInterface $logger,
+		?Telemetry $telemetry = null
+	) {
 		$options->assertRequiredOptions( self::CONSTRUCTOR_OPTIONS );
 		$this->options = $options;
 		$this->logger = $logger;
+		$this->telemetry = $telemetry;
 	}
 
 	/**
@@ -87,8 +95,8 @@ class HttpRequestFactory {
 	 *    - originalRequest     Information about the original request (as a WebRequest object or
 	 *                          an associative array with 'ip' and 'userAgent').
 	 * @phpcs:ignore Generic.Files.LineLength
-	 * @phan-param array{timeout?:int|string,connectTimeout?:int|string,postData?:string|array,proxy?:?string,noProxy?:bool,sslVerifyHost?:bool,sslVerifyCert?:bool,caInfo?:?string,maxRedirects?:int,followRedirects?:bool,userAgent?:string,method?:string,logger?:\Psr\Log\LoggerInterface,username?:string,password?:string,originalRequest?:\WebRequest|array{ip:string,userAgent:string}} $options
-	 * @param string $caller The method making this request, for profiling
+	 * @phan-param array{timeout?:int|string,connectTimeout?:int|string,postData?:string|array,proxy?:?string,noProxy?:bool,sslVerifyHost?:bool,sslVerifyCert?:bool,caInfo?:?string,maxRedirects?:int,followRedirects?:bool,userAgent?:string,method?:string,logger?:\Psr\Log\LoggerInterface,username?:string,password?:string,originalRequest?:\MediaWiki\Request\WebRequest|array{ip:string,userAgent:string}} $options
+	 * @param string $caller The method making this request, for profiling @phan-mandatory-param
 	 * @return MWHttpRequest
 	 * @see MWHttpRequest::__construct
 	 */
@@ -108,8 +116,11 @@ class HttpRequestFactory {
 			$this->options->get( MainConfigNames::HTTPConnectTimeout ),
 			$this->options->get( MainConfigNames::HTTPMaxConnectTimeout ) ?: INF
 		);
-
-		return new GuzzleHttpRequest( $url, $options, $caller, Profiler::instance() );
+		$client = new GuzzleHttpRequest( $url, $options, $caller, Profiler::instance() );
+		if ( $this->telemetry ) {
+			$client->addTelemetry( $this->telemetry );
+		}
+		return $client;
 	}
 
 	/**
@@ -125,23 +136,19 @@ class HttpRequestFactory {
 	private function normalizeTimeout( $parameter, $maxParameter, $default, $maxConfigured ) {
 		if ( $parameter === 'default' || $parameter === null ) {
 			if ( !is_numeric( $default ) ) {
-				throw new \InvalidArgumentException(
+				throw new InvalidArgumentException(
 					'$wgHTTPTimeout and $wgHTTPConnectTimeout must be set to a number' );
 			}
 			$value = $default;
 		} else {
 			$value = $parameter;
 		}
-		if ( $maxParameter !== null ) {
-			$max = $maxParameter;
-		} else {
-			$max = $maxConfigured;
-		}
+		$max = $maxParameter ?? $maxConfigured;
 		if ( $max && $value > $max ) {
 			return $max;
-		} else {
-			return $value;
 		}
+
+		return $value;
 	}
 
 	/**
@@ -161,7 +168,7 @@ class HttpRequestFactory {
 	 * @param string $url Full URL to act on. If protocol-relative, will be expanded to an http://
 	 *  URL
 	 * @param array $options See HttpRequestFactory::create
-	 * @param string $caller The method making this request, for profiling
+	 * @param string $caller The method making this request, for profiling @phan-mandatory-param
 	 * @return string|null null on failure or a string on success
 	 */
 	public function request( $method, $url, array $options = [], $caller = __METHOD__ ) {
@@ -176,7 +183,7 @@ class HttpRequestFactory {
 		if ( $status->isOK() ) {
 			return $req->getContent();
 		} else {
-			$errors = $status->getErrorsByType( 'error' );
+			$errors = array_map( fn ( $msg ) => $msg->getKey(), $status->getMessages( 'error' ) );
 			$logger->warning( Status::wrap( $status )->getWikiText( false, false, 'en' ),
 				[ 'error' => $errors, 'caller' => $caller, 'content' => $req->getContent() ] );
 			return null;
@@ -184,12 +191,12 @@ class HttpRequestFactory {
 	}
 
 	/**
-	 * Simple wrapper for request( 'GET' ), parameters have same meaning as for request()
+	 * Simple wrapper for `request( 'GET' )`, parameters have the same meaning as for `request()`
 	 *
 	 * @since 1.34
 	 * @param string $url
 	 * @param array $options
-	 * @param string $caller
+	 * @param string $caller @phan-mandatory-param
 	 * @return string|null
 	 */
 	public function get( $url, array $options = [], $caller = __METHOD__ ) {
@@ -197,12 +204,12 @@ class HttpRequestFactory {
 	}
 
 	/**
-	 * Simple wrapper for request( 'POST' ), parameters have same meaning as for request()
+	 * Simple wrapper for `request( 'POST' )`, parameters have the same meaning as for `request()`
 	 *
 	 * @since 1.34
 	 * @param string $url
 	 * @param array $options
-	 * @param string $caller
+	 * @param string $caller @phan-mandatory-param
 	 * @return string|null
 	 */
 	public function post( $url, array $options = [], $caller = __METHOD__ ) {
@@ -249,6 +256,7 @@ class HttpRequestFactory {
 			'logger' => $this->logger,
 			'localProxy' => $this->options->get( MainConfigNames::LocalHTTPProxy ),
 			'localVirtualHosts' => $this->options->get( MainConfigNames::LocalVirtualHosts ),
+			'telemetry' => Telemetry::getInstance(),
 		];
 		return new MultiHttpClient( $options );
 	}
@@ -284,6 +292,11 @@ class HttpRequestFactory {
 		if ( !isset( $config['headers']['User-Agent'] ) ) {
 			$config['headers']['User-Agent'] = $this->getUserAgent();
 		}
+		if ( $this->telemetry ) {
+			$config['headers'] = array_merge(
+				$this->telemetry->getRequestHeaders(), $config['headers']
+			);
+		}
 
 		return new Client( $config );
 	}
