@@ -18,6 +18,9 @@
  * @file
  */
 
+use MediaWiki\Message\Message;
+use Wikimedia\Message\MessageSpecifier;
+
 /**
  * Interface for localizing messages in MediaWiki
  *
