@@ -1,5 +1,8 @@
 <?php
 
+use MediaWiki\Content\ContentHandler;
+use MediaWiki\SpecialPage\SpecialPage;
+
 class ContentModelLogFormatter extends LogFormatter {
 	protected function getMessageParameters() {
 		$lang = $this->context->getLanguage();
