@@ -1,7 +1,5 @@
 <?php
 /**
- * Implements Special:Filepath
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -18,18 +16,23 @@
  * http://www.gnu.org/copyleft/gpl.html
  *
  * @file
- * @ingroup SpecialPage
  */
 
+namespace MediaWiki\Specials;
+
+use MediaWiki\SpecialPage\RedirectSpecialPage;
+use MediaWiki\SpecialPage\SpecialPage;
+use MediaWiki\Title\Title;
+use SearchEngineFactory;
+
 /**
- * A special page that redirects to the URL of a given file
+ * Redirects to the URL of a thumbnail for the given file.
  *
  * @ingroup SpecialPage
  */
 class SpecialFilepath extends RedirectSpecialPage {
 
-	/** @var SearchEngineFactory */
-	private $searchEngineFactory;
+	private SearchEngineFactory $searchEngineFactory;
 
 	/**
 	 * @param SearchEngineFactory $searchEngineFactory
@@ -95,3 +98,6 @@ class SpecialFilepath extends RedirectSpecialPage {
 		return 'media';
 	}
 }
+
+/** @deprecated class alias since 1.41 */
+class_alias( SpecialFilepath::class, 'SpecialFilepath' );
