@@ -1,7 +1,5 @@
 <?php
 /** Bulgarian (български)
- *
- * To improve a translation please visit https://translatewiki.net
  *
  * @file
  * @ingroup Languages
@@ -94,6 +92,7 @@ $specialPageAliases = [
 	'Randomredirect'            => [ 'Случайно_пренасочване' ],
 	'Recentchanges'             => [ 'Последни_промени' ],
 	'Recentchangeslinked'       => [ 'Свързани_промени' ],
+	'Renameuser'                => [ 'Преименуване' ],
 	'Revisiondelete'            => [ 'Изтриване_на_версии' ],
 	'Search'                    => [ 'Търсене' ],
 	'Shortpages'                => [ 'Кратки_страници' ],
@@ -162,7 +161,7 @@ $magicWords = [
 	'img_width'                 => [ '1', '$1пкс', '$1п', '$1px' ],
 	'index'                     => [ '1', '__ИНДЕКСИРАНЕ__', '__INDEX__' ],
 	'int'                       => [ '0', 'ВЪТР:', 'INT:' ],
-	'language'                  => [ '0', '#ЕЗИК:', '#LANGUAGE:' ],
+	'language'                  => [ '0', '#ЕЗИК', '#LANGUAGE' ],
 	'lc'                        => [ '0', 'МБ:', 'LC:' ],
 	'lcfirst'                   => [ '0', 'МБПЪРВА:', 'LCFIRST:' ],
 	'localurl'                  => [ '0', 'ЛОКАЛЕНАДРЕС:', 'LOCALURL:' ],
