@@ -1,7 +1,5 @@
 <?php
 /** Greek (Ελληνικά)
- *
- * To improve a translation please visit https://translatewiki.net
  *
  * @file
  * @ingroup Languages
@@ -127,6 +125,7 @@ $specialPageAliases = [
 	'Recentchanges'             => [ 'ΠρόσφατεςΑλλαγές' ],
 	'Recentchangeslinked'       => [ 'ΣυνδεδεμένεςΠρόσφατεςΑλλαγές', 'ΣχετικέςΑλλαγές' ],
 	'Redirect'                  => [ 'Ανακατεύθυνση' ],
+	'Renameuser'                => [ 'ΜετονομασίαΧρήστη' ],
 	'Revisiondelete'            => [ 'ΔιαγραφήΈκδοσης' ],
 	'Search'                    => [ 'Αναζήτηση' ],
 	'Shortpages'                => [ 'ΜικρέςΣελίδες' ],
@@ -218,7 +217,7 @@ $magicWords = [
 	'img_width'                 => [ '1', '$1εσ', '$1px' ],
 	'index'                     => [ '1', '__ΕΥΡΕΤΗΡΙΟ__', '__INDEX__' ],
 	'int'                       => [ '0', 'ΕΣΩΤ:', 'INT:' ],
-	'language'                  => [ '0', '#ΓΛΩΣΣΑ:', '#LANGUAGE:' ],
+	'language'                  => [ '0', '#ΓΛΩΣΣΑ', '#LANGUAGE' ],
 	'lc'                        => [ '0', 'ΠΕΖΑ:', 'LC:' ],
 	'lcfirst'                   => [ '0', 'ΠΡΩΤΟΠΕΖΟ:', 'LCFIRST:' ],
 	'localday'                  => [ '1', 'ΤΟΠΙΚΗΜΕΡΑ', 'LOCALDAY' ],
