@@ -1,7 +1,5 @@
 <?php
 /** Kazakh (Arabic script) (قازاقشا (تٴوتە))
- *
- * To improve a translation please visit https://translatewiki.net
  *
  * @file
  * @ingroup Languages
@@ -217,7 +215,7 @@ $magicWords = [
 	'img_upright'               => [ '1', 'تىكتى', 'تىكتىك=$1', 'تىكتىك $1', 'тікті', 'тіктік=$1', 'тіктік $1', 'upright', 'upright=$1', 'upright $1' ],
 	'img_width'                 => [ '1', '$1 نۇكتە', '$1 нүкте', '$1px' ],
 	'int'                       => [ '0', 'ىشكى:', 'ІШКІ:', 'INT:' ],
-	'language'                  => [ '0', '#تىل:', '#ТІЛ:', '#LANGUAGE:' ],
+	'language'                  => [ '0', '#تىل', '#ТІЛ', '#LANGUAGE' ],
 	'lc'                        => [ '0', 'كا:', 'كىشىارىپپەن:', 'КӘ:', 'КІШІӘРІППЕН:', 'LC:' ],
 	'lcfirst'                   => [ '0', 'كا1:', 'كىشىارىپپەن1:', 'КӘ1:', 'КІШІӘРІППЕН1:', 'LCFIRST:' ],
 	'localday'                  => [ '1', 'جەرگىلىكتىكۇن', 'ЖЕРГІЛІКТІКҮН', 'LOCALDAY' ],
