@@ -1,7 +1,5 @@
 <?php
 /** Sanskrit (संस्कृतम्)
- *
- * To improve a translation please visit https://translatewiki.net
  *
  * @file
  * @ingroup Languages
@@ -230,7 +228,7 @@ $1', 'सङ्कुचितचित्र=$1', 'अङ्गुष्ठ=$1'
 	'img_upright'               => [ '1', 'शीर्षदक्षिणतः', 'शीर्षदक्षिणतः=$1', 'शीर्षदक्षिणतः_$1', 'उन्नत', 'उन्नत=$1', 'उन्नत $1', 'upright', 'upright=$1', 'upright $1' ],
 	'img_width'                 => [ '1', '$1अणवः', '$1पिट', '$1px' ],
 	'index'                     => [ '1', '__अनुक्रमणी__', '__अनुक्रमणिका__', '__INDEX__' ],
-	'language'                  => [ '0', '#भाषा', '#भाषा:', '#LANGUAGE:' ],
+	'language'                  => [ '0', '#भाषा', '#भाषा', '#LANGUAGE' ],
 	'localday'                  => [ '1', 'स्थानिकदिवसः', 'स्थानिकदिवसे', 'LOCALDAY' ],
 	'localday2'                 => [ '1', 'स्थानिकदिवसः२', 'स्थानिकदिवसे२', 'LOCALDAY2' ],
 	'localdayname'              => [ '1', 'स्थानिकदिवसनाम', 'स्थानिकदिवसेनाम', 'LOCALDAYNAME' ],
@@ -276,7 +274,7 @@ $1', 'सङ्कुचितचित्र=$1', 'अङ्गुष्ठ=$1'
 	'sitename'                  => [ '1', 'स्थाननाम', 'स्थलनाम', 'SITENAME' ],
 	'special'                   => [ '0', 'विशेषः', 'विशेष', 'special' ],
 	'staticredirect'            => [ '1', '__अनित्यपुनर्निर्देशनम्__', '__अनित्यपुनर्निदेशन__', '__STATICREDIRECT__' ],
-	'subjectpagename'           => [ '1',  'विषयपृष्ठनाम', 'लेखपृष्ठनाम', 'SUBJECTPAGENAME', 'ARTICLEPAGENAME' ],
+	'subjectpagename'           => [ '1', 'विषयपृष्ठनाम', 'लेखपृष्ठनाम', 'SUBJECTPAGENAME', 'ARTICLEPAGENAME' ],
 	'subjectspace'              => [ '1', 'विषयस्थानम्', 'लेखस्थानम्', 'विषयविश्व', 'लेखविश्व', 'SUBJECTSPACE', 'ARTICLESPACE' ],
 	'subpagename'               => [ '1', 'उपपृष्ठनाम', 'SUBPAGENAME' ],
 	'tag'                       => [ '0', 'अङ्कनम्', 'वीजक', 'tag' ],
