@@ -23,9 +23,9 @@
  * @todo Make this more useful, right now just dumps content language
  */
 
-use MediaWiki\MediaWikiServices;
-
+// @codeCoverageIgnoreStart
 require_once __DIR__ . '/../Maintenance.php';
+// @codeCoverageIgnoreEnd
 
 /**
  * Maintenance script that dumps an entire language, using the keys from English.
@@ -41,9 +41,9 @@ class DumpMessages extends Maintenance {
 
 	public function execute() {
 		$messages = [];
-		$localisationCache = MediaWikiServices::getInstance()->getLocalisationCache();
+		$localisationCache = $this->getServiceContainer()->getLocalisationCache();
 		$localisationMessagesEn = $localisationCache->getItem( 'en', 'messages' );
-		foreach ( array_keys( $localisationMessagesEn ) as $key ) {
+		foreach ( $localisationMessagesEn as $key => $_ ) {
 			$messages[$key] = wfMessage( $key )->text();
 		}
 		$this->output( "MediaWiki " . MW_VERSION . " language file\n" );
@@ -51,5 +51,7 @@ class DumpMessages extends Maintenance {
 	}
 }
 
+// @codeCoverageIgnoreStart
 $maintClass = DumpMessages::class;
 require_once RUN_MAINTENANCE_IF_MAIN;
+// @codeCoverageIgnoreEnd
