@@ -1,9 +1,8 @@
 /**
  * @private
- * @class jQuery.plugin.footHovzer
  */
 ( function () {
-	var $hovzer, footHovzer, $spacer;
+	let $hovzer, footHovzer = null, $spacer;
 
 	function getHovzer() {
 		if ( $hovzer === undefined ) {
@@ -15,12 +14,12 @@
 	/**
 	 * Utility to stack stuff in an overlay fixed on the bottom of the page.
 	 *
-	 * Usage:
-	 *
-	 *     var hovzer = $.getFootHovzer();
-	 *     hovzer.$.append( $myCollection );
-	 *     hovzer.update();
+	 * @example
+	 * var hovzer = $.getFootHovzer();
+	 * hovzer.$.append( $myCollection );
+	 * hovzer.update();
 	 *
+	 * @private
 	 * @static
 	 * @inheritable
 	 * @return {jQuery.footHovzer}
@@ -44,16 +43,14 @@
 		 * Update dimensions of stack to account for changes in the subtree.
 		 */
 		update: function () {
-			var $body;
-
-			$body = $( document.body );
+			const $body = $( document.body );
 
 			if ( $spacer === undefined ) {
 				$spacer = $( '<div>' ).attr( 'id', 'jquery-foot-hovzer-spacer' );
 				$spacer.appendTo( $body );
 			}
 			// Ensure CSS is applied by browser before using .outerHeight()
-			setTimeout( function () {
+			setTimeout( () => {
 				$spacer.css( 'height', getHovzer().outerHeight( /* includeMargin = */ true ) );
 			}, 0 );
 		}
@@ -61,7 +58,7 @@
 
 	/**
 	 * @class jQuery
-	 * @mixins jQuery.plugin.footHovzer
+	 * @mixes jQuery.plugin.footHovzer
 	 */
 
 }() );
