@@ -1,12 +1,16 @@
 <?php
 
+use MediaWiki\Context\RequestContext;
 use MediaWiki\MainConfigNames;
+use MediaWiki\Output\OutputPage;
+use MediaWiki\Request\ContentSecurityPolicy;
+use MediaWiki\Title\Title;
 use PHPUnit\Framework\MockObject\MockObject;
 
 /**
- * @covers SkinMustache
- *
- * @group Output
+ * @covers \SkinMustache
+ * @group Skin
+ * @group Database
  */
 class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 
@@ -18,9 +22,6 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 	private function getMockOutputPage( $html, $title ) {
 		$mockContentSecurityPolicy = $this->createMock( ContentSecurityPolicy::class );
 
-		$mockContentSecurityPolicy->method( 'getNonce' )
-			->willReturn( 'secret' );
-
 		$mock = $this->createMock( OutputPage::class );
 		$mock->method( 'getHTML' )
 			->willReturn( $html );
@@ -33,15 +34,13 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 		$mock->method( 'getTitle' )
 			->willReturn( $title );
 		$mock->method( 'getIndicators' )
-			->willReturn( '' );
+			->willReturn( [ '' ] );
 		$mock->method( 'getLanguageLinks' )
 			->willReturn( [] );
-		$mock->method( 'getCSP' )
-			->willReturn( $mockContentSecurityPolicy );
 		$mock->method( 'isTOCEnabled' )
 			->willReturn( true );
-		$mock->method( 'getSections' )
-			->willReturn( [] );
+		$mock->method( 'getTOCData' )
+			->willReturn( null );
 		return $mock;
 	}
 
@@ -52,7 +51,7 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 			return;
 		} elseif ( is_array( $value ) ) {
 			$this->assertTrue(
-				strpos( $key, 'data-' ) === 0 || strpos( $key, 'array-' ) === 0,
+				str_starts_with( $key, 'data-' ) || str_starts_with( $key, 'array-' ),
 				"Template data that is an object should be associated with a key" .
 				" prefixed with `data-` or `array-` ($key)"
 			);
@@ -70,20 +69,20 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 				}
 			}
 		} elseif ( is_string( $value ) ) {
-			if ( strpos( $value, '<' ) !== false ) {
+			if ( str_contains( $value, '<' ) ) {
 				$this->assertTrue(
-					strpos( $key, 'html-' ) === 0 || $key === 'html',
+					str_starts_with( $key, 'html-' ) || $key === 'html',
 					"Template data containing HTML must be prefixed with `html-` ($key)"
 				);
 			}
 		} elseif ( is_bool( $value ) ) {
 			$this->assertTrue(
-				strpos( $key, 'is-' ) === 0 || strpos( $key, 'has-' ) === 0,
+				str_starts_with( $key, 'is-' ) || str_starts_with( $key, 'has-' ),
 				"Template data containing booleans must be prefixed with `is-` or `has-` ($key)"
 			);
 		} elseif ( is_numeric( $value ) ) {
 			$this->assertTrue(
-				strpos( $key, 'number-' ) === 0,
+				str_starts_with( $key, 'number-' ),
 				"Template data containing numbers must be prefixed with `number-` ($key)"
 			);
 		} else {
@@ -94,10 +93,11 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 	}
 
 	/**
-	 * @covers Skin::getTemplateData
-	 * @covers MediaWiki\Skin\SkinComponentLogo::getTemplateData
-	 * @covers MediaWiki\Skin\SkinComponentSearch::getTemplateData
-	 * @covers MediaWiki\Skin\SkinComponentTableOfContents::getTemplateData
+	 * @covers \Skin
+	 * @covers \MediaWiki\Skin\SkinComponentLogo
+	 * @covers \MediaWiki\Skin\SkinComponentSearch
+	 * @covers \MediaWiki\Skin\SkinComponentTableOfContents
+	 * @covers \MediaWiki\Skin\SkinComponentFooter
 	 */
 	public function testGetTemplateData() {
 		$config = $this->getServiceContainer()->getMainConfig();
@@ -117,13 +117,13 @@ class SkinMustacheTest extends MediaWikiIntegrationTestCase {
 		$data = $skin->getTemplateData();
 
 		// Validate the default template data respects the naming rules
-		foreach ( array_keys( $data ) as $key ) {
+		foreach ( $data as $key => $_ ) {
 			$this->validateTemplateData( $data, $key );
 		}
 
 		// Validate search data
 		$searchData = $data['data-search-box'];
-		foreach ( array_keys( $searchData ) as $key ) {
+		foreach ( $searchData as $key => $_ ) {
 			$this->validateTemplateData( $searchData, $key );
 		}
 	}
