@@ -1,8 +1,15 @@
 <?php
 
+use MediaWiki\Context\RequestContext;
+use MediaWiki\Language\ILanguageConverter;
 use MediaWiki\Languages\LanguageConverterFactory;
 use MediaWiki\MainConfigNames;
 use MediaWiki\MediaWikiServices;
+use MediaWiki\Request\FauxRequest;
+use MediaWiki\Search\TitleMatcher;
+use MediaWiki\Specials\SpecialSearch;
+use MediaWiki\Title\Title;
+use MediaWiki\User\User;
 
 /**
  * Test class for SpecialSearch class
@@ -23,12 +30,15 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			$services->getInterwikiLookup(),
 			$services->getReadOnlyMode(),
 			$services->getUserOptionsManager(),
-			$services->getLanguageConverterFactory()
+			$services->getLanguageConverterFactory(),
+			$services->getRepoGroup(),
+			$services->getSearchResultThumbnailProvider(),
+			$services->getTitleMatcher()
 		);
 	}
 
 	/**
-	 * @covers SpecialSearch::load
+	 * @covers \MediaWiki\Specials\SpecialSearch::load
 	 */
 	public function testAlternativeBackend() {
 		$this->overrideConfigValue( MainConfigNames::SearchTypeAlternatives, [ 'MockSearchEngine' ] );
@@ -48,8 +58,8 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 	}
 
 	/**
-	 * @covers SpecialSearch::load
-	 * @covers SpecialSearch::showResults
+	 * @covers \MediaWiki\Specials\SpecialSearch::load
+	 * @covers \MediaWiki\Specials\SpecialSearch::showResults
 	 */
 	public function testValidateSortOrder() {
 		$ctx = new RequestContext();
@@ -63,13 +73,13 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			->getSpecialPageFactory()
 			->executePath( $sp, $ctx );
 		$html = $ctx->getOutput()->getHTML();
-		$this->assertRegExp( '/class="mw-message-box-warning/', $html, 'must contain warnings' );
-		$this->assertRegExp( '/Sort order of invalid is unrecognized/',
+		$this->assertStringContainsString( 'cdx-message--warning', $html, 'must contain warnings' );
+		$this->assertMatchesRegularExpression( '/Sort order of invalid is unrecognized/',
 			$html, 'must tell user sort order is invalid' );
 	}
 
 	/**
-	 * @covers SpecialSearch::load
+	 * @covers \MediaWiki\Specials\SpecialSearch::load
 	 * @dataProvider provideSearchOptionsTests
 	 * @param array $requested Request parameters. For example:
 	 *   [ 'ns5' => true, 'ns6' => true ]. Null to use default options.
@@ -87,7 +97,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			$this->newUserWithSearchNS( $userOptions )
 		);
 		/*
-		$context->setRequest( new FauxRequest( [
+		$context->setRequest( new MediaWiki\Request\FauxRequest( [
 			'ns5'=>true,
 			'ns6'=>true,
 		] ));
@@ -140,11 +150,11 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			],
 			[
 				$EMPTY_REQUEST, [
-				'searchNs2' => 1,
-				'searchNs14' => 1,
-			] + array_fill_keys( array_map( static function ( $ns ) {
-				return "searchNs$ns";
-			}, $defaultNS ), 0 ),
+					'searchNs2' => 1,
+					'searchNs14' => 1,
+				] + array_fill_keys( array_map( static function ( $ns ) {
+					return "searchNs$ns";
+				}, $defaultNS ), 0 ),
 				'advanced', [ 2, 14 ],
 				'T35583: search with no option should honor User search preferences'
 					. ' and have all other namespace disabled'
@@ -174,7 +184,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 	/**
 	 * Verify we do not expand search term in <title> on search result page
 	 * https://gerrit.wikimedia.org/r/4841
-	 * @covers SpecialSearch::setupPage
+	 * @covers \MediaWiki\Specials\SpecialSearch::setupPage
 	 */
 	public function testSearchTermIsNotExpanded() {
 		// T303046
@@ -185,7 +195,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 		$ctx = new RequestContext();
 		$term = '{{SITENAME}}';
 		$ctx->setRequest( new FauxRequest( [ 'search' => $term, 'fulltext' => 1 ] ) );
-		$ctx->setTitle( Title::newFromText( 'Special:Search' ) );
+		$ctx->setTitle( Title::makeTitle( NS_SPECIAL, 'Search' ) );
 		$search = $this->newSpecialPage();
 		$search->setContext( $ctx );
 
@@ -199,14 +209,14 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			->getHTMLTitle();
 
 		# Compare :-]
-		$this->assertRegExp(
+		$this->assertMatchesRegularExpression(
 			'/' . preg_quote( $term, '/' ) . '/',
 			$pageTitle,
 			"Search term '{$term}' should not be expanded in Special:Search <title>"
 		);
 	}
 
-	public function provideRewriteQueryWithSuggestion() {
+	public static function provideRewriteQueryWithSuggestion() {
 		return [
 			[
 				'With suggestion and no rewritten query shows did you mean',
@@ -252,7 +262,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 
 	/**
 	 * @dataProvider provideRewriteQueryWithSuggestion
-	 * @covers SpecialSearch::showResults
+	 * @covers \MediaWiki\Specials\SpecialSearch::showResults
 	 */
 	public function testRewriteQueryWithSuggestion(
 		$message,
@@ -282,7 +292,10 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 				$services->getInterwikiLookup(),
 				$services->getReadOnlyMode(),
 				$services->getUserOptionsManager(),
-				$services->getLanguageConverterFactory()
+				$services->getLanguageConverterFactory(),
+				$services->getRepoGroup(),
+				$services->getSearchResultThumbnailProvider(),
+				$services->getTitleMatcher()
 			] )
 			->onlyMethods( [ 'getSearchEngine' ] )
 			->getMock();
@@ -296,11 +309,11 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 
 		$html = $search->getContext()->getOutput()->getHTML();
 		foreach ( (array)$expectRegex as $regex ) {
-			$this->assertRegExp( $regex, $html, $message );
+			$this->assertMatchesRegularExpression( $regex, $html, $message );
 		}
 	}
 
-	public function provideLimitPreference() {
+	public static function provideLimitPreference() {
 		return [
 			[ 20, 20 ],
 			[ 101, null ],
@@ -309,7 +322,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 
 	/**
 	 * @dataProvider provideLimitPreference
-	 * @covers SpecialSearch::showResults
+	 * @covers \MediaWiki\Specials\SpecialSearch::showResults
 	 */
 	public function testLimitPreference(
 		$optionValue,
@@ -325,7 +338,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 
 		$userOptionsManager = $this->getServiceContainer()->getUserOptionsManager();
 
-		$user = User::newFromName( 'UTSysop' );
+		$user = $this->getTestSysop()->getUser();
 		$userOptionsManager->setOption( $user, 'searchlimit', $optionValue );
 		$user->saveSettings();
 
@@ -340,7 +353,10 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 				$services->getInterwikiLookup(),
 				$services->getReadOnlyMode(),
 				$userOptionsManager,
-				$services->getLanguageConverterFactory()
+				$services->getLanguageConverterFactory(),
+				$services->getRepoGroup(),
+				$services->getSearchResultThumbnailProvider(),
+				$services->getTitleMatcher()
 			] )
 			->onlyMethods( [ 'getSearchEngine' ] )
 			->getMock();
@@ -355,44 +371,33 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 
 		$html = $search->getContext()->getOutput()->getHTML();
 		if ( $expectedLimit === null ) {
-			$this->assertNotRegExp( "/ title=\"Next \\d+ results\"/", $html );
+			$this->assertDoesNotMatchRegularExpression( "/ title=\"Next \\d+ results\"/", $html );
 		} else {
-			$this->assertRegExp( "/ title=\"Next $expectedLimit results\"/", $html );
+			$this->assertMatchesRegularExpression( "/ title=\"Next $expectedLimit results\"/", $html );
 		}
 	}
 
 	protected function mockSearchEngine( SpecialSearchTestMockResultSet $results ) {
 		$mock = $this->getMockBuilder( SearchEngine::class )
-			->onlyMethods( [ 'searchText', 'searchTitle', 'getNearMatcher' ] )
+			->onlyMethods( [ 'searchText' ] )
 			->getMock();
 
 		$mock->method( 'searchText' )
 			->willReturn( $results );
 
-		$nearMatcherMock = $this->getMockBuilder( SearchNearMatcher::class )
-			->disableOriginalConstructor()
-			->onlyMethods( [ 'getNearMatch' ] )
-			->getMock();
-
-		$nearMatcherMock->method( 'getNearMatch' )
-			->willReturn( $results->getFirstResult() );
-
-		$mock->method( 'getNearMatcher' )
-			->willReturn( $nearMatcherMock );
-
 		$mock->setHookContainer( $this->getServiceContainer()->getHookContainer() );
 
 		return $mock;
 	}
 
 	/**
-	 * @covers SpecialSearch::execute
+	 * @covers \MediaWiki\Specials\SpecialSearch::execute
 	 */
 	public function testSubPageRedirect() {
 		$this->overrideConfigValue( MainConfigNames::Script, '/w/index.php' );
 
 		$ctx = new RequestContext;
-		$sp = Title::newFromText( 'Special:Search/foo_bar' );
+		$sp = Title::makeTitle( NS_SPECIAL, 'Search/foo_bar' );
 		$this->getServiceContainer()->getSpecialPageFactory()->executePath( $sp, $ctx );
 		$url = $ctx->getOutput()->getRedirect();
 
@@ -407,7 +412,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 	 * If the 'search-match-redirect' user pref is false, then SpecialSearch::goResult() should
 	 * return null
 	 *
-	 * @covers SpecialSearch::goResult
+	 * @covers \MediaWiki\Specials\SpecialSearch::goResult
 	 */
 	public function testGoResult_userPrefRedirectOn() {
 		$context = new RequestContext;
@@ -428,7 +433,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 	 * If the 'search-match-redirect' user pref is true, then SpecialSearch::goResult() should
 	 * NOT return null if there is a near match found for the search term
 	 *
-	 * @covers SpecialSearch::goResult
+	 * @covers \MediaWiki\Specials\SpecialSearch::goResult
 	 */
 	public function testGoResult_userPrefRedirectOff() {
 		// mock the search engine so it returns a near match for an arbitrary search term
@@ -437,6 +442,15 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 			'',
 			[ SearchResult::newFromTitle( Title::newMainPage() ) ]
 		);
+
+		$nearMatcherMock = $this->getMockBuilder( TitleMatcher::class )
+			->disableOriginalConstructor()
+			->onlyMethods( [ 'getNearMatch' ] )
+			->getMock();
+
+		$nearMatcherMock->method( 'getNearMatch' )
+			->willReturn( $searchResults->getFirstResult() );
+
 		$mockSearchEngine = $this->mockSearchEngine( $searchResults );
 		$services = $this->getServiceContainer();
 		$search = $this->getMockBuilder( SpecialSearch::class )
@@ -448,7 +462,10 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 				$services->getInterwikiLookup(),
 				$services->getReadOnlyMode(),
 				$services->getUserOptionsManager(),
-				$services->getLanguageConverterFactory()
+				$services->getLanguageConverterFactory(),
+				$services->getRepoGroup(),
+				$services->getSearchResultThumbnailProvider(),
+				$nearMatcherMock
 			] )
 			->onlyMethods( [ 'getSearchEngine' ] )
 			->getMock();
@@ -470,8 +487,7 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 	}
 
 	/**
-	 * @covers SpecialSearch::showResults
-	 * @throws MWException
+	 * @covers \MediaWiki\Specials\SpecialSearch::showResults
 	 */
 	public function test_create_link_not_shown_if_variant_link_is_known() {
 		$searchTerm = "Test create link not shown if variant link is known";
@@ -515,7 +531,10 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 				$services->getInterwikiLookup(),
 				$services->getReadOnlyMode(),
 				$services->getUserOptionsManager(),
-				$languageConverterFactory
+				$languageConverterFactory,
+				$services->getRepoGroup(),
+				$services->getSearchResultThumbnailProvider(),
+				$services->getTitleMatcher()
 			);
 			$context = new RequestContext();
 			$context->setRequest( new FauxRequest() );
@@ -538,61 +557,3 @@ class SpecialSearchTest extends MediaWikiIntegrationTestCase {
 		$this->assertStringNotContainsString( 'class="mw-search-exists"', $html );
 	}
 }
-
-class SpecialSearchTestMockResultSet extends SearchResultSet {
-	protected $results;
-	protected $suggestion;
-	protected $rewrittenQuery;
-	protected $containedSyntax;
-
-	public function __construct(
-		$suggestion = null,
-		$rewrittenQuery = null,
-		array $results = [],
-		$containedSyntax = false
-	) {
-		$this->suggestion = $suggestion;
-		$this->rewrittenQuery = $rewrittenQuery;
-		$this->results = $results;
-		$this->containedSyntax = $containedSyntax;
-	}
-
-	public function expandResults() {
-		return $this->results;
-	}
-
-	public function getTotalHits() {
-		return $this->numRows();
-	}
-
-	public function hasSuggestion() {
-		return $this->suggestion !== null;
-	}
-
-	public function getSuggestionQuery() {
-		return $this->suggestion;
-	}
-
-	public function getSuggestionSnippet() {
-		return $this->suggestion;
-	}
-
-	public function hasRewrittenQuery() {
-		return $this->rewrittenQuery !== null;
-	}
-
-	public function getQueryAfterRewrite() {
-		return $this->rewrittenQuery;
-	}
-
-	public function getQueryAfterRewriteSnippet() {
-		return htmlspecialchars( $this->rewrittenQuery );
-	}
-
-	public function getFirstResult() {
-		if ( count( $this->results ) === 0 ) {
-			return null;
-		}
-		return $this->results[0]->getTitle();
-	}
-}
