@@ -1,9 +1,15 @@
 <?php
 
+use MediaWiki\Api\ApiMain;
+use MediaWiki\Api\ApiQueryGeneratorBase;
+use MediaWiki\Request\FauxRequest;
+
 /**
  * Checks that all API query modules, core and extensions, have unique prefixes.
  *
  * @group API
+ * @group Database
+ * @coversNothing
  */
 class ApiPrefixUniquenessTest extends MediaWikiIntegrationTestCase {
 
@@ -20,7 +26,7 @@ class ApiPrefixUniquenessTest extends MediaWikiIntegrationTestCase {
 			$class = get_class( $module );
 
 			$prefix = $module->getModulePrefix();
-			if ( $prefix === '' /* HACK: T196962 */ || $prefix === 'wbeu' ) {
+			if ( $prefix === '' ) {
 				continue;
 			}
 
