@@ -1,10 +1,12 @@
 <?php
 
+use MediaWiki\Password\Argon2Password;
+
 /**
  * @group large
- * @covers Argon2Password
- * @covers Password
- * @covers ParameterizedPassword
+ * @covers \MediaWiki\Password\Argon2Password
+ * @covers \MediaWiki\Password\Password
+ * @covers \MediaWiki\Password\ParameterizedPassword
  */
 class Argon2PasswordTest extends PasswordTestCase {
 
@@ -36,7 +38,7 @@ class Argon2PasswordTest extends PasswordTestCase {
 	 * @return array
 	 */
 	public static function providePasswordTests() {
-		$result = [
+		return [
 			[
 				true,
 				':argon2:$argon2i$v=19$m=1024,t=2,p=2$RHpGTXJPeFlSV2NDTEswNA$VeW7rumZY4pL8XO4KeQkKD43r5uX3eazVJRtrFN7lNc',
@@ -56,15 +58,14 @@ class Argon2PasswordTest extends PasswordTestCase {
 				false,
 				':argon2:$argon2i$v=19$m=1024,t=2,p=2$UGZqTWJRUkI1alVNTGRUbA$RcASw9XUWjCDO9WNnuVkGkEylURUW/CcNwSffdFwN74',
 				'password',
+			],
+			// argon2id
+			[
+				true,
+				':argon2:$argon2id$v=19$m=65536,t=1,p=1$SS51Z0U2bkQ5Mk1GYUNQOQ$jdN3UnHn6MHOaOeWiX+RqRhcwVPLLDlEAKPvDt/qKIY',
+				'password'
 			]
 		];
-
-		if ( defined( 'PASSWORD_ARGON2ID' ) ) {
-			// @todo: Argon2id cases
-			$result = array_merge( $result, [] );
-		}
-
-		return $result;
 	}
 
 	/**
@@ -75,7 +76,7 @@ class Argon2PasswordTest extends PasswordTestCase {
 		$this->assertSame( $updateExpected, $password->needsUpdate() );
 	}
 
-	public function provideNeedsUpdate() {
+	public static function provideNeedsUpdate() {
 		return [
 			[ false, ':argon2:$argon2i$v=19$m=1024,t=2,p=2$bFJ4TzM5RWh2T0VmeFhDTA$AHFUFZRh69aZYBqyxn6tpujpEcf2JP8wgRCPU3nw3W4' ],
 			[ false, ':argon2:$argon2i$v=19$m=1024,t=2,p=2$<whatever>' ],
@@ -84,31 +85,4 @@ class Argon2PasswordTest extends PasswordTestCase {
 			[ true, ':argon2:$argon2i$v=19$m=1024,t=2,p=666$<whatever>' ],
 		];
 	}
-
-	public function testPartialConfig() {
-		// The default options changed in PHP 7.2.21 and 7.3.8. This seems to be the only way to
-		// fetch them at runtime.
-		$options = password_get_info( password_hash( '', PASSWORD_ARGON2I ) )['options'];
-
-		$factory = new PasswordFactory();
-		$factory->register( 'argon2', [
-			'class' => Argon2Password::class,
-			'algo' => 'argon2i',
-		] );
-
-		$partialPassword = $factory->newFromType( 'argon2' );
-		$partialPassword->crypt( 'password' );
-
-		$factory2 = new PasswordFactory();
-		$factory2->register( 'argon2', [
-			'class' => Argon2Password::class,
-			'algo' => 'argon2i',
-		] + $options );
-
-		$fullPassword = $factory2->newFromCiphertext( $partialPassword->toString() );
-
-		$this->assertFalse( $fullPassword->needsUpdate(),
-			'Options not set for a password should fall back to defaults'
-		);
-	}
 }
