@@ -1,13 +1,13 @@
 'use strict';
 
-const assert = require( 'assert' );
 const Api = require( 'wdio-mediawiki/Api' );
 const WatchlistPage = require( '../pageobjects/watchlist.page' );
 const WatchablePage = require( '../pageobjects/watchable.page' );
 const LoginPage = require( 'wdio-mediawiki/LoginPage' );
+const BlankPage = require( 'wdio-mediawiki/BlankPage' );
 const Util = require( 'wdio-mediawiki/Util' );
 
-describe( 'Special:Watchlist', function () {
+describe( 'Special:Watchlist', () => {
 	let bot;
 
 	before( async () => {
@@ -15,13 +15,16 @@ describe( 'Special:Watchlist', function () {
 		bot = await Api.bot();
 	} );
 
-	beforeEach( function () {
-		LoginPage.loginAdmin();
+	beforeEach( async () => {
+		await LoginPage.loginAdmin();
 	} );
 
-	it( 'should show page with new edit', async function () {
+	// Skipped on 2022-12-07 in 865696 because of T324237
+	it.skip( 'should show page with new edit @daily', async function () {
 		const title = Util.getTestString( 'Title-' );
 
+		// First try to load a blank page, so the next command works.
+		await BlankPage.open();
 		// Don't try to run wikitext-specific tests if the test namespace isn't wikitext by default.
 		if ( await Util.isTargetNotWikitext( title ) ) {
 			this.skip();
@@ -41,7 +44,7 @@ describe( 'Special:Watchlist', function () {
 		// but by default Special:Watchlist includes both seen and unseen changes, so
 		// it'll show up anyway. The title we just edited will be first because the edit
 		// was the most recent.
-		assert.strictEqual( await WatchlistPage.titles[ 0 ].getText(), title );
+		await expect( await WatchlistPage.titles[ 0 ] ).toHaveText( title );
 	} );
 
 } );
